==> tuia-advert-center-api-2.4.3-sources.jar: cn/com/duiba/tuia/core/api/dto/MaterialAuditDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

public class MaterialAuditDataDto {
    /**
     * 广告计划id
     */
    private Long advertId;
    /**
     * 素材id
     */
    private Long materialId;

    /**
     * 素材名称
     */
    private String materialName;
    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 广告主id
     */
    private Long accountId;

    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 一级代理商id
     */
    private Long levelOneAgentId;
    /**
     * 一级代理商名称
     */
    private String levelOneAgentName;

    /**
     * ae id
     */
    private Long aeId;
    private String aeName;
    private Long sellId;
    private String sellName;

    /**
     * 素材地址
     */
    private String materialUrl;

    private Integer checkType;
    /**
     * 审核人.
     */
    private String reviewer;

    private String reason;

    // 素材类型,0-素材,1-弹层
    private Integer materialType;

    /**
     * 进审时间
     */
    private String enterCheckTime;
    /**
     * 审核时间
     */
    private String checkTime;
    /**
     * 审核时长
     */
    private Long checkCostTime;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getLevelOneAgentId() {
        return levelOneAgentId;
    }

    public void setLevelOneAgentId(Long levelOneAgentId) {
        this.levelOneAgentId = levelOneAgentId;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getMaterialUrl() {
        return materialUrl;
    }

    public void setMaterialUrl(String materialUrl) {
        this.materialUrl = materialUrl;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public Integer getMaterialType() {
        return materialType;
    }

    public void setMaterialType(Integer materialType) {
        this.materialType = materialType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(String enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }

    public Long getCheckCostTime() {
        return checkCostTime;
    }

    public void setCheckCostTime(Long checkCostTime) {
        this.checkCostTime = checkCostTime;
    }
}

==> tuia-advert-center-api-2.4.78-sources.jar: cn/com/duiba/tuia/core/api/dto/MaterialAuditDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

public class MaterialAuditDataDto {
    /**
     * 广告计划id
     */
    private Long advertId;
    /**
     * 素材id
     */
    private Long materialId;

    /**
     * 素材名称
     */
    private String materialName;
    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 广告主id
     */
    private Long accountId;

    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 一级代理商id
     */
    private Long levelOneAgentId;
    /**
     * 一级代理商名称
     */
    private String levelOneAgentName;

    /**
     * ae id
     */
    private Long aeId;
    private String aeName;
    private Long sellId;
    private String sellName;

    /**
     * 素材地址
     */
    private String materialUrl;

    private Integer checkType;
    /**
     * 审核人.
     */
    private String reviewer;

    private String reason;

    // 素材类型,0-素材,1-弹层
    private Integer materialType;

    /**
     * 进审时间
     */
    private String enterCheckTime;
    /**
     * 审核时间
     */
    private String checkTime;
    /**
     * 审核时长
     */
    private Long checkCostTime;

    /**
     * 代理商ID.
     */
    private Long agentId;

    /**
     * 代理商公司名.
     */
    private String agentCompanyName;

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getLevelOneAgentId() {
        return levelOneAgentId;
    }

    public void setLevelOneAgentId(Long levelOneAgentId) {
        this.levelOneAgentId = levelOneAgentId;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getMaterialUrl() {
        return materialUrl;
    }

    public void setMaterialUrl(String materialUrl) {
        this.materialUrl = materialUrl;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public Integer getMaterialType() {
        return materialType;
    }

    public void setMaterialType(Integer materialType) {
        this.materialType = materialType;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(String enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }

    public Long getCheckCostTime() {
        return checkCostTime;
    }

    public void setCheckCostTime(Long checkCostTime) {
        this.checkCostTime = checkCostTime;
    }
}
